@@ -14,6 +14,8 @@ const ELVISH_SCRIPT: &str = include_str!("argc.elv");
 
 const NUSHELL_SCRIPT: &str = include_str!("argc.nu");
 
+const XONSH_SCRIPT: &str = include_str!("argc.xsh");
+
 pub fn generate(shell: Shell, args: &[String]) -> Result<String> {
     let mut cmds = vec!["argc"];
     cmds.extend(args.iter().map(|v| v.as_str()));
@@ -22,23 +24,6 @@ pub fn generate(shell: Shell, args: &[String]) -> Result<String> {
             let code = format!("complete -F _argc_completer {}", cmds.join(" "));
             format!("{BASH_SCRIPT}\n{code}\n",)
         }
-        Shell::Zsh => {
-            let code = format!("compdef _argc_completer {}", cmds.join(" "));
-            format!("{ZSH_SCRIPT}\n{code}\n",)
-        }
-        Shell::Powershell => {
-            let lines: Vec<String> = cmds.iter().map(|v| format!("Register-ArgumentCompleter -Native -ScriptBlock $_argc_completer -CommandName {v} ")).collect();
-            let code = lines.join("\n");
-            format!("{POWERSHELL_SCRIPT}\n{code}\n",)
-        }
-        Shell::Fish => {
-            let lines: Vec<String> = cmds
-                .iter()
-                .map(|v| format!(r#"complete -x -c {v} -a "(_argc_completer)""#))
-                .collect();
-            let code = lines.join("\n");
-            format!("{FISH_SCRIPT}\n{code}\n",)
-        }
         Shell::Elvish => {
             let lines: Vec<String> = cmds
                 .iter()
@@ -47,6 +32,14 @@ pub fn generate(shell: Shell, args: &[String]) -> Result<String> {
             let code = lines.join("\n");
             format!("{ELVISH_SCRIPT}\n{code}\n",)
         }
+        Shell::Fish => {
+            let lines: Vec<String> = cmds
+                .iter()
+                .map(|v| format!(r###"complete -x -c {v} -a "(_argc_completer)" -r"###))
+                .collect();
+            let code = lines.join("\n");
+            format!("{FISH_SCRIPT}\n{code}\n",)
+        }
         Shell::Nushell => {
             let code = format!("{cmds:?}");
             format!(
@@ -70,6 +63,19 @@ $env.config.completions.external = {{
 "###,
             )
         }
+        Shell::Powershell => {
+            let lines: Vec<String> = cmds.iter().map(|v| format!("Register-ArgumentCompleter -Native -ScriptBlock $_argc_completer -CommandName {v} ")).collect();
+            let code = lines.join("\n");
+            format!("{POWERSHELL_SCRIPT}\n{code}\n",)
+        }
+        Shell::Xonsh => {
+            let code = format!("ARGC_SCRIPTS={cmds:?}");
+            format!("{XONSH_SCRIPT}\n{code}\n",)
+        }
+        Shell::Zsh => {
+            let code = format!("compdef _argc_completer {}", cmds.join(" "));
+            format!("{ZSH_SCRIPT}\n{code}\n",)
+        }
     };
     Ok(output)
 }
