@@ -12,7 +12,7 @@ use indexmap::{IndexMap, IndexSet};
 
 const KNOWN_OPTIONS: [&str; 6] = ["-h", "-help", "--help", "-V", "-version", "--version"];
 
-pub struct Matcher<'a, 'b> {
+pub(crate) struct Matcher<'a, 'b> {
     cmds: Vec<(&'b str, &'a Command, String)>,
     args: &'b [String],
     flag_option_args: Vec<Vec<FlagOptionArg<'a, 'b>>>,
@@ -28,7 +28,7 @@ pub struct Matcher<'a, 'b> {
 type FlagOptionArg<'a, 'b> = (&'b str, Vec<&'b str>, Option<&'a str>);
 
 #[derive(Debug, PartialEq, Eq)]
-pub enum ArgComp {
+pub(crate) enum ArgComp {
     FlagOrOption,
     FlagOrOptionCombine(String),
     CommandOrPositional,
@@ -37,7 +37,7 @@ pub enum ArgComp {
 }
 
 #[derive(Debug)]
-pub enum MatchError {
+pub(crate) enum MatchError {
     DisplayHelp,
     DisplaySubcommandHelp(String),
     DisplayVersion,
@@ -51,7 +51,7 @@ pub enum MatchError {
 }
 
 impl<'a, 'b> Matcher<'a, 'b> {
-    pub fn new(root: &'a Command, args: &'b [String]) -> Self {
+    pub(crate) fn new(root: &'a Command, args: &'b [String]) -> Self {
         let mut cmds = vec![(args[0].as_str(), root, args[0].clone())];
         let mut cmd_level = 0;
         let mut arg_index = 1;
@@ -160,26 +160,21 @@ impl<'a, 'b> Matcher<'a, 'b> {
         }
     }
 
-    pub fn set_script_path(&mut self, script_path: &str) {
+    pub(crate) fn set_script_path(&mut self, script_path: &str) {
         self.script_path = Some(script_path.to_string());
         let fns: Vec<&str> = self.choices_fns.iter().copied().collect();
-        if let Some(list) = run_param_fns(script_path, &fns, self.args) {
-            for (i, fn_output) in list.into_iter().enumerate() {
-                let choices: Vec<String> = fn_output
-                    .split('\n')
-                    .map(|v| v.trim().to_string())
-                    .filter(|v| !v.is_empty())
-                    .collect();
+        if let Some(list) = run_param_fns(script_path, &fns, self.args, HashMap::new()) {
+            for (i, choices) in list.into_iter().enumerate() {
                 self.choices_values.insert(fns[i], choices);
             }
         }
     }
 
-    pub fn set_term_width(&mut self, term_width: usize) {
+    pub(crate) fn set_term_width(&mut self, term_width: usize) {
         self.term_width = Some(term_width);
     }
 
-    pub fn to_arg_values(&self) -> Vec<ArgcValue> {
+    pub(crate) fn to_arg_values(&self) -> Vec<ArgcValue> {
         if let Some(err) = self.validate() {
             return vec![ArgcValue::Error(self.stringify_match_error(&err))];
         }
@@ -196,7 +191,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
         output
     }
 
-    pub fn to_arg_values_for_choice_fn(&self) -> Vec<ArgcValue> {
+    pub(crate) fn to_arg_values_for_choice_fn(&self) -> Vec<ArgcValue> {
         let mut output: Vec<ArgcValue> = self.to_arg_values_base();
         if !self.dashdash.is_empty() {
             output.push(ArgcValue::Multiple(
@@ -211,7 +206,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
         output
     }
 
-    pub fn compgen(&self) -> Vec<(String, String)> {
+    pub(crate) fn compgen(&self) -> Vec<(String, String)> {
         match &self.arg_comp {
             ArgComp::FlagOrOption => self.comp_flag_options(),
             ArgComp::FlagOrOptionCombine(value) => {
@@ -259,11 +254,10 @@ impl<'a, 'b> Matcher<'a, 'b> {
                 if self.positional_args.len() == 2 && self.positional_args[0] == "help" {
                     return comp_subcomands(cmd);
                 }
-                let mut output = if !self.dashdash.is_empty() {
-                    vec![]
-                } else {
-                    self.comp_flag_options()
-                };
+                let mut output = vec![];
+                if cmd.positional_params.is_empty() {
+                    output.extend(self.comp_flag_options());
+                }
                 let values = self.match_positionals();
                 output.extend(comp_subcommands_positional(
                     cmd,
@@ -527,6 +521,7 @@ impl<'a, 'b> Matcher<'a, 'b> {
 
     fn stringify_match_error(&self, err: &MatchError) -> (String, i32) {
         let mut exit = 0;
+        let footer = "For more information, try '--help'.";
         let message = match err {
             MatchError::DisplayHelp => {
                 let (cmd, cmd_paths) = self.get_cmd_and_paths(self.cmds.len() - 1);
@@ -549,12 +544,12 @@ impl<'a, 'b> Matcher<'a, 'b> {
                 let usage = cmd.render_usage(&cmd_paths);
                 let names = cmd.list_subcommand_names().join(", ");
                 format!(
-                    r###"error: '{cmd_str}' requires a subcommand but one was not provided
+                    r###"error: `{cmd_str}` requires a subcommand but one was not provided
   [subcommands: {names}]
 
 {usage}
 
-For more information, try '--help'.
+{footer}
 "###
                 )
             }
@@ -563,11 +558,11 @@ For more information, try '--help'.
                 let (cmd, cmd_paths) = self.get_cmd_and_paths(*level);
                 let usage = cmd.render_usage(&cmd_paths);
                 format!(
-                    r###"error: unexpected argument '{name}' found
+                    r###"error: unexpected argument `{name}` found
 
 {usage}
 
-For more information, try '--help'.
+{footer}
 "###
                 )
             }
@@ -586,7 +581,7 @@ For more information, try '--help'.
 
 {usage}
 
-For more information, try '--help'.
+{footer}
 "###
                 )
             }
@@ -595,11 +590,11 @@ For more information, try '--help'.
                 let (cmd, cmd_paths) = self.get_cmd_and_paths(*level);
                 let usage = cmd.render_usage(&cmd_paths);
                 format!(
-                    r###"error: the argument '{name}' cannot be used multiple times
+                    r###"error: the argument `{name}` cannot be used multiple times
 
 {usage}
 
-For more information, try '--help'.
+{footer}
 "###
                 )
             }
@@ -607,10 +602,10 @@ For more information, try '--help'.
                 exit = 1;
                 let list = choices.join(", ");
                 format!(
-                    r###"error: invalid value '{value}' for '{name}'
+                    r###"error: invalid value `{value}` for `{name}`
   [possible values: {list}]
 
-For more information, try '--help'.
+{footer}
 "###
                 )
             }
@@ -619,11 +614,11 @@ For more information, try '--help'.
                 let (cmd, cmd_paths) = self.get_cmd_and_paths(*level);
                 let usage = cmd.render_usage(&cmd_paths);
                 format!(
-                    r###"error: invalid values for '{value}'
+                    r###"error: invalid values for `{value}`
 
 {usage}
 
-For more information, try '--help'.
+{footer}
 "###
                 )
             }
@@ -632,11 +627,11 @@ For more information, try '--help'.
                 let (cmd, cmd_paths) = self.get_cmd_and_paths(*level);
                 let usage = cmd.render_usage(&cmd_paths);
                 format!(
-                    r###"error: unexpected value '{value}' for '{name}' found; no more were expected 
+                    r###"error: unexpected value `{value}` for `{name}` found; no more were expected 
 
 {usage}
 
-For more information, try '--help'.
+{footer}
 "###
                 )
             }
@@ -741,10 +736,10 @@ fn match_flag_option<'a, 'b>(
 fn comp_subcommands_positional(
     cmd: &Command,
     values: &[Vec<&str>],
-    subcmd: bool,
+    with_subcmd: bool,
 ) -> Vec<(String, String)> {
     let mut output = vec![];
-    if subcmd {
+    if with_subcmd {
         output.extend(comp_subcomands(cmd))
     }
     if values.is_empty() || values.len() > cmd.positional_params.len() {
@@ -776,8 +771,6 @@ fn comp_flag_option(param: &FlagOptionParam, index: usize) -> Vec<(String, Strin
         value_name,
         &param.choices,
         &param.choices_fn,
-        param.multiple,
-        param.required,
     )
 }
 
@@ -787,8 +780,6 @@ fn comp_positional(param: &PositionalParam) -> Vec<(String, String)> {
         &param.arg_value_name,
         &param.choices,
         &param.choices_fn,
-        param.multiple,
-        param.required,
     )
 }
 
@@ -797,8 +788,6 @@ fn comp_param(
     value_name: &str,
     choices: &Option<Vec<String>>,
     choices_fn: &Option<(String, bool)>,
-    multiple: bool,
-    required: bool,
 ) -> Vec<(String, String)> {
     let choices: Option<Either<Vec<String>, String>> = if let Some(choices_fn) = choices_fn {
         Some(Either::Right(choices_fn.0.to_string()))
@@ -816,12 +805,7 @@ fn comp_param(
             Either::Right(choices_fn) => vec![(format!("__argc_fn:{}", choices_fn), String::new())],
         }
     } else {
-        let value = match (multiple, required) {
-            (true, true) => format!("__argc_value+{}", value_name),
-            (true, false) => format!("__argc_value*{}", value_name),
-            (false, true) => format!("__argc_value!{}", value_name),
-            (false, false) => format!("__argc_value:{}", value_name),
-        };
+        let value = format!("__argc_value:{}", value_name);
         vec![(value, describe.into())]
     }
 }
