@@ -1,5 +1,6 @@
 use convert_case::{Boundary, Converter, Pattern};
 use std::{
+    collections::HashMap,
     env,
     path::{Path, PathBuf},
     process, thread,
@@ -32,7 +33,7 @@ pub fn is_default_value_terminate(c: char) -> bool {
 }
 
 pub fn get_shell_path() -> Option<PathBuf> {
-    let shell = match env::var("ARGC_SHELL") {
+    let shell = match env::var("ARGC_SHELL_PATH") {
         Ok(v) => Path::new(&v).to_path_buf(),
         Err(_) => get_bash_path()?,
     };
@@ -61,7 +62,8 @@ pub fn run_param_fns(
     script_file: &str,
     param_fns: &[&str],
     args: &[String],
-) -> Option<Vec<String>> {
+    envs: HashMap<String, String>,
+) -> Option<Vec<Vec<String>>> {
     let shell = get_shell_path()?;
     let shell_extra_args = if shell
         .file_stem()
@@ -82,12 +84,14 @@ pub fn run_param_fns(
             let param_fn = param_fn.to_string();
             let shell = shell.clone();
             let shell_extra_args = shell_extra_args.clone();
+            let envs = envs.clone();
             thread::spawn(move || {
                 process::Command::new(shell)
                     .args(shell_extra_args)
                     .arg(&script_file)
                     .arg(&param_fn)
                     .args(args)
+                    .envs(envs)
                     .env("PATH", path_env)
                     .output()
                     .ok()
@@ -96,9 +100,16 @@ pub fn run_param_fns(
             })
         })
         .collect();
-    let list: Vec<String> = handles
+    let list: Vec<Vec<String>> = handles
         .into_iter()
         .map(|h| h.join().ok().unwrap_or_default())
+        .map(|v| {
+            v.split('\n')
+                .map(|v| v.trim())
+                .filter(|v| !v.is_empty())
+                .map(|v| v.to_string())
+                .collect()
+        })
         .collect();
     Some(list)
 }
@@ -107,6 +118,12 @@ pub fn termwidth() -> Option<usize> {
     env::var("TERM_WIDTH").ok()?.parse().ok()
 }
 
+pub fn get_current_dir() -> Option<String> {
+    env::current_dir()
+        .ok()
+        .map(|v| v.to_string_lossy().to_string())
+}
+
 fn path_env_with_exe() -> String {
     let mut path_env = std::env::var("PATH").ok().unwrap_or_default();
     if let Some(exe_dir) = std::env::current_exe()
