@@ -13,6 +13,7 @@ fn multiple() {
         script,
         vec![
             vec!["prog", ""],
+            vec!["prog", "-"],
             vec!["prog", "--"],
             vec!["prog", "--", ""],
             vec!["prog", "-f", ""],
@@ -326,3 +327,109 @@ cmdb() { :; }
         ]
     );
 }
+
+#[test]
+fn no_flags_options() {
+    let script = r###"
+# @cmd
+# @flag --fa
+# @option --oa  <file>
+no_arg() { :; }
+
+# @cmd
+# @flag --fa
+# @option --oa  <file>
+# @arg file
+arg() { :; }
+"###;
+
+    snapshot_compgen!(
+        script,
+        vec![vec!["prog", "no_arg", ""], vec!["prog", "arg", ""]]
+    );
+}
+
+#[test]
+fn parts() {
+    let script = r###"
+# @option --oa*[`_choice_fn`]
+_choice_fn() {
+    echo __argc_parts:/
+	echo A/B
+	echo A/B/C
+    echo A/C
+    echo B/C
+    echo C
+}
+"###;
+
+    snapshot_compgen!(
+        script,
+        vec![
+            vec!["prog", "--oa", ""],
+            vec!["prog", "--oa", "A/"],
+            vec!["prog", "--oa", "A/B/"],
+        ]
+    );
+}
+
+#[test]
+fn no_space() {
+    let script = r###"
+# @option --oa*[`_choice_fn`]
+_choice_fn() {
+	echo -e "abc"
+	echo -e "def\0"
+	echo -e "ghk\thello world"
+}
+"###;
+
+    snapshot_compgen_shells!(script, vec!["prog", "--oa", ""]);
+}
+
+#[test]
+fn value_display() {
+    let script = r###"
+# @option --oa*[`_choice_fn`]
+_choice_fn() {
+	echo "abc:def:xyz"
+	echo "abc:def:tsr"
+	echo "abc:ijk:abc"
+	echo "abc:ijk:xyz"
+}
+"###;
+
+    snapshot_compgen_shells!(script, vec!["prog", "--oa="]);
+}
+
+#[test]
+fn parts_shell() {
+    let script = r###"
+# @option --oa*[`_choice_fn`]
+_choice_fn() {
+    echo __argc_parts:/
+	echo A/B
+	echo A/B/
+	echo A/B/C
+	echo A/B/D
+}
+"###;
+
+    snapshot_compgen_shells!(script, vec!["prog", "--oa", "A/"]);
+}
+
+#[test]
+fn parts2_shell() {
+    let script = r###"
+# @option --oa*[`_choice_fn`]
+_choice_fn() {
+    echo __argc_parts:/
+	echo A/B
+	echo A/B/
+	echo A/B/C
+	echo A/B/D
+}
+"###;
+
+    snapshot_compgen_shells!(script, vec!["prog", "--oa", "A/B/"]);
+}
